@@ -182,6 +182,16 @@ module Debci
       status
     end
 
+    def expired?
+      days = Debci.config.data_retention_days.to_i
+      if days > 0
+        retention_window = days * (24*60*60)
+        Time.now > self.date + retention_window
+      else
+        false
+      end
+    end
+
     def inspect
       "<#{suite}/#{architecture} #{status}>"
     end
