@@ -8,12 +8,18 @@ case $- in
     ;;
 esac
 
+call_chdist() {
+  local cmd="$1"
+  shift
+  chdist --arch "$debci_arch" --data-dir "${debci_data_basedir}/chdist" "$cmd" "${debci_suite}-${debci_arch}" "$@"
+}
+
 grep_packages() {
-  chdist --data-dir "${debci_data_basedir}/chdist" grep-dctrl-packages ${debci_suite}-${debci_arch} "$@"
+  call_chdist grep-dctrl-packages "$@"
 }
 
 grep_sources() {
-  chdist --data-dir "${debci_data_basedir}/chdist" grep-dctrl-sources ${debci_suite}-${debci_arch} "$@"
+  call_chdist grep-dctrl-sources "$@"
 }
 
 
@@ -107,9 +113,9 @@ report_status() {
         color=5 # should never get here though
         ;;
     esac
-    log "${pkg} \033[38;5;${color}m${status}\033[m" "$duration"
+    log "${pkg} ${debci_suite}/${debci_arch} \033[38;5;${color}m${status}\033[m" "$duration"
   else
-    log "$pkg" "$status" "$duration"
+    log "$pkg ${debci_suite}/${debci_arch}" "$status" "$duration"
   fi >&2
 }
 
