@@ -19,12 +19,17 @@ check_shell_usage() {
     failed_checks=$(($failed_checks + 1))
   fi
 
+  if ! shellcheck --external-sources --shell dash "$script" >/dev/null 2>&1; then
+    # not failing on shellcheck issues yet
+    echo "W: shellcheck reports warnings on $script; please fix them"
+  fi
+
   return $failed_checks
 }
 scripts="$(cd $base && find bin/ backends -type f -executable | xargs grep -l '#!/bin/sh') $(cd $base && echo lib/*.sh)"
 script_test_names=""
 
-for f in $scripts lib/*.sh; do
+for f in $scripts; do
   ff=$(echo "$f" | sed -e 's/[^a-zA-Z0-9]\+/_/g')
   script_test_names="${script_test_names} test_${ff}"
   eval "test_$ff() { check_shell_usage '$base/$f' || assertTrue \"$f shell usage problems. See messages above\" '${SHUNIT_FALSE}'; }"
